This function creates an identifier by combining abbreviated species names or taxon IDs. For species names, it uses the first letter of the genus and the first two letters of the species. For single-word names, it appends "sp". For numeric taxon IDs, it prefixes them with "tid_".

.generateDBname(user_bacs)

Arguments

user_bacs

Character vector containing mixed inputs of taxon IDs and/or species names.

Defaults to c("90371", "Bacillus subtilis").

Value

A single character string representing the combined shortened name.

Examples

if (FALSE) { # \dontrun{
.generateDBname(c("90371", "Bacillus subtilis"))
.generateDBname(c("12345", "Escherichia coli", "Lactobacillus"))
} # }